==> ckan-2.1.tar.gz: ckan-2.1/ckan/public/base/i18n/fi.js <==
{
  "": {
    "domain": "ckan",
    "lang": "fi",
    "plural-forms": "nplurals=2; plural=(n != 1);"
  },
  "An Error Occurred": [
    null,
    "Tapahtui virhe"
  ],
  "Are you sure you want to perform this action?": [
    null,
    "Oletko varma, että haluat tehdä tämän?"
  ],
  "Cancel": [
    null,
    "Peruuta"
  ],
  "Confirm": [
    null,
    "Vahvista"
  ],
  "Edit": [
    null,
    "Muokkaa"
  ],
  "Failed to load data API information": [
    null,
    "Data API:n tietojen lataaminen epäonnistui"
  ],
  "Follow": [
    null,
    "Seuraa"
  ],
  "Hide": [
    null,
    "Piilota"
  ],
  "Input is too short, must be at least one character": [
    null,
    "Liian lyhyt, pitää olla vähintään yksi merkki"
  ],
  "Loading...": [
    null,
    "Ladataan..."
  ],
  "No matches found": [
    null,
    "Ei yhtään osumaa"
  ],
  "Please Confirm Action": [
    null,
    "Vahvista toimenpide"
  ],
  "Resource uploaded": [
    null,
    "Resurssi on ladattu"
  ],
  "Show more": [
    null,
    "Näytä enemmän"
  ],
  "Start typing…": [
    null,
    "Ala kirjoittamaan..."
  ],
  "There are unsaved modifications to this form": [
    null,
    "Lomakkeella on tallentamattomia tietoja"
  ],
  "There is no API data to load for this resource": [
    null,
    "API:n kautta ei ole ladattavissa dataa tälle resurssille"
  ],
  "URL": [
    null,
    "URL"
  ],
  "Unable to authenticate upload": [
    null,
    "Lataamisen autentikointi epäonnistui"
  ],
  "Unable to get data for uploaded file": [
    null,
    "Datan saamien ladattavalle tiedostolle epäonnistui"
  ],
  "Unable to upload file": [
    null,
    "Tiedoston lataaminen epäonnistui"
  ],
  "Unfollow": [
    null,
    "Lopeta seuraaminen"
  ],
  "Upload a file": [
    null,
    "Tallenna tiedosto"
  ],
  "show less": [
    null,
    "näytä vähemmän"
  ],
  "show more": [
    null,
    "näytä lisää"
  ]
}

==> ckan-2.2.tar.gz: ckan-2.2/ckan/public/base/i18n/fi.js <==
{
  "": {
    "domain": "ckan",
    "lang": "fi",
    "plural-forms": "nplurals=2; plural=(n != 1);"
  },
  "An Error Occurred": [
    null,
    "Tapahtui virhe"
  ],
  "Are you sure you want to perform this action?": [
    null,
    "Oletko varma, että haluat tehdä tämän?"
  ],
  "Cancel": [
    null,
    "Peruuta"
  ],
  "Confirm": [
    null,
    "Vahvista"
  ],
  "Edit": [
    null,
    "Muokkaa"
  ],
  "Failed to load data API information": [
    null,
    "Data API:n tietojen lataaminen epäonnistui"
  ],
  "Follow": [
    null,
    "Seuraa"
  ],
  "Hide": [
    null,
    "Piilota"
  ],
  "Image": [
    null,
    "Kuva"
  ],
  "Input is too short, must be at least one character": [
    null,
    "Liian lyhyt, pitää olla vähintään yksi merkki"
  ],
  "Link": [
    null,
    "Linkki"
  ],
  "Link to a URL on the internet (you can also link to an API)": [
    null,
    "Linkki URL-osoitteeseen intterneteissä (voit myös linkittää API:in)"
  ],
  "Loading...": [
    null,
    "Ladataan..."
  ],
  "No matches found": [
    null,
    "Ei yhtään osumaa"
  ],
  "Please Confirm Action": [
    null,
    "Vahvista toimenpide"
  ],
  "Remove": [
    null,
    "Poista"
  ],
  "Reorder resources": [
    null,
    "Uudelleenjärjestä resurssit"
  ],
  "Reset this": [
    null,
    "Resetoi tämä"
  ],
  "Resource uploaded": [
    null,
    "Resurssi on ladattu"
  ],
  "Save order": [
    null,
    "Tallenna tilaus"
  ],
  "Saving...": [
    null,
    "Tallentaa..."
  ],
  "Show more": [
    null,
    "Näytä enemmän"
  ],
  "Start typing…": [
    null,
    "Ala kirjoittamaan..."
  ],
  "There are unsaved modifications to this form": [
    null,
    "Lomakkeella on tallentamattomia tietoja"
  ],
  "There is no API data to load for this resource": [
    null,
    "API:n kautta ei ole ladattavissa dataa tälle resurssille"
  ],
  "URL": [
    null,
    "URL"
  ],
  "Unable to authenticate upload": [
    null,
    "Lataamisen autentikointi epäonnistui"
  ],
  "Unable to get data for uploaded file": [
    null,
    "Datan saamien ladattavalle tiedostolle epäonnistui"
  ],
  "Unable to upload file": [
    null,
    "Tiedoston lataaminen epäonnistui"
  ],
  "Unfollow": [
    null,
    "Lopeta seuraaminen"
  ],
  "Upload": [
    null,
    "Lataa"
  ],
  "Upload a file": [
    null,
    "Tallenna tiedosto"
  ],
  "Upload a file on your computer": [
    null,
    "Lataa tiedosto työasemalta"
  ],
  "You are uploading a file. Are you sure you want to navigate away and stop this upload?": [
    null,
    "Olet olet parhaillaan lataamassa tiedostoa palvelimelle. Oletko varma että haluat navigoida sivukta ja keskeyttää lataamisen?"
  ],
  "show less": [
    null,
    "näytä vähemmän"
  ],
  "show more": [
    null,
    "näytä lisää"
  ]
}
